'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _knex = require('knex');

var _knex2 = _interopRequireDefault(_knex);

var _qutureApp = require('quture-app');

var _qutureApp2 = _interopRequireDefault(_qutureApp);

var _qutureConfig = require('quture-config');

var _qutureConfig2 = _interopRequireDefault(_qutureConfig);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var Database = function () {

  /**
   * Create a new {Database} instance.
   *
   * @param {Quture} quture
   * @param {string} migrationCommand
   */
  function Database(quture) {
    _classCallCheck(this, Database);

    var self = this;

    this._quture = quture;
    this._config = new _qutureConfig2.default({
      configDir: _path2.default.join(this._quture.getConfig().getConfigDirectory(), 'database')
    });

    /**
     * Publish configuration file
     */
    this._quture.publishConfigurationFile(this._config, _path2.default.join(__dirname, 'config', 'connection.js'));

    /**
     * Configure knex
     */
    this._migrationsDir = this._config.get('connection.migrations', _path2.default.join(this._quture.getRootDirectory(), 'migrations'));

    var options = {
      client: this._config.get('connection.dialect', 'sqlite'),
      connection: {
        host: this._config.get('connection.host', '127.0.0.1'),
        user: this._config.get('connection.username', 'root'),
        password: this._config.get('connection.password', ''),
        database: this._config.get('connection.database', 'quture'),
        filename: this._config.get('connection.storage', _path2.default.join(this._quture.getStorageDirectory(), 'database.sqlite'))
      },
      migrations: {
        directory: this._migrationsDir,
        tableName: 'migrations'
      }
    };

    /**
     * Instantiate knex
     */
    this._knex = (0, _knex2.default)(options);

    /**
     * Setup getQutureDatabase() method for allowing
     * the ability to retrieve this instance from
     * within migrations.
     */
    this._knex.getQutureDatabase = function () {
      return this;
    };
  }

  /**
   * Retrieve the {Knex} instance.
   *
   * @returns {Knex}
   */


  _createClass(Database, [{
    key: 'knex',
    value: function knex() {
      return this._knex;
    }

    /**
     * Retrieve the migrations directory path.
     *
     * @return {string}
     */

  }, {
    key: 'getMigrationsDirectory',
    value: function getMigrationsDirectory() {
      return this._migrationsDir;
    }

    /**
     * Check if the migration file with the specified name
     * is already published to the migrations folder.
     *
     * @param {string} fileName
     * @returns {boolean}
     */

  }, {
    key: 'isMigrationPublished',
    value: function isMigrationPublished(fileName) {
      return _qutureApp2.default.getUtilities().isFilePublished(fileName, this.getMigrationsDirectory());
    }

    /**
     * Publish the specified migration file into the
     * migration folder.
     *
     * @param {string} filePath
     */

  }, {
    key: 'publishMigration',
    value: function publishMigration(filePath) {
      return _qutureApp2.default.getUtilities().publishFile(filePath, this.getMigrationsDirectory());
    }
  }]);

  return Database;
}();

exports.default = Database;
module.exports = exports['default'];