'use strict';

import path from 'path';
import chai from 'chai';
import fsx from 'fs-extra';
import Quture from 'quture-app';
import Config from 'quture-config';
import Database from '../src/database';

describe('quture-database', function() {

  let rootDir = path.join(__dirname);
  let configPath = path.join(__dirname, 'config');
  let viewsPath = path.join(__dirname, 'views');
  let publicPath = path.join(__dirname, 'public');
  let storagePath = path.join(__dirname, 'storage');

  /**
   * Setup chai
   */
  before(function(done) {
    fs.removeSync(configPath);
    fs.removeSync(viewsPath);
    fs.removeSync(publicPath);
    fs.removeSync(storagePath);

    fs.ensureDirSync(configPath);
    done();
  });

  it('should create a valid Database instance', function(done) {
    let qutureInstance = new Quture({
      rootDir,
      config: new Config({
        configDir: configPath
      })
    })

    let databaseInstance = new Database(qutureInstance);

    if (databaseInstance) {
      done();
    } else {
      done(new Error('Unable to create a database instance'));
    }
  });



});
